@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aeson-pretty
 version: 0.7.2
-id: aeson-pretty-0.7.2-fd291a527e7a9e0cfcb7ebbe367215f0
-key: aeson_DTQ94dGtMxj46h2TfrFAzG
+id: aeson-pretty-0.7.2-8174b19ca10259cc67493f0b5e4f0938
+key: aeson_8Jlbec9kldS6CZWyTnufnG
 license: BSD3
 copyright: Copyright 2011 Falko Peters
 maintainer: Falko Peters <falko.peters@gmail.com>
@@ -34,13 +34,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-pretty-0.7.2
-hs-libraries: HSaeson-pretty-0.7.2-DTQ94dGtMxj46h2TfrFAzG
+hs-libraries: HSaeson-pretty-0.7.2-8Jlbec9kldS6CZWyTnufnG
 depends:
-    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
 haddock-html: /usr/share/doc/haskell-aeson-pretty/html
